@@ -1042,7 +1042,7 @@ void do_get(char *rname,char *lname,file_info *finfo1)
   int datalen=0;
 
   struct timeval tp_start;
-  gettimeofday(&tp_start,NULL);
+  GetTimeOfDay(&tp_start);
 
   if (finfo1) 
     finfo = *finfo1;
@@ -1304,7 +1304,7 @@ void do_get(char *rname,char *lname,file_info *finfo1)
 		continue;
 	      }
 
-	    if(read_data(Client,inbuf,datalen,False) != datalen) {
+	    if(read_data(Client,inbuf,datalen) != datalen) {
 	      DEBUG(0,("Failed to read data in readbraw\n"));
 	      exit(1);
 	    }
@@ -1395,7 +1395,7 @@ void do_get(char *rname,char *lname,file_info *finfo1)
     struct timeval tp_end;
     int this_time;
 
-    gettimeofday(&tp_end,NULL);
+    GetTimeOfDay(&tp_end);
     this_time = 
       (tp_end.tv_sec - tp_start.tv_sec)*1000 +
 	(tp_end.tv_usec - tp_start.tv_usec)/1000;
@@ -1721,7 +1721,7 @@ void do_put(char *rname,char *lname,file_info *finfo)
   time_t close_time = finfo->mtime;
 
   struct timeval tp_start;
-  gettimeofday(&tp_start,NULL);
+  GetTimeOfDay(&tp_start);
 
   inbuf = (char *)malloc(BUFFER_SIZE + SAFETY_MARGIN);
   outbuf = (char *)malloc(BUFFER_SIZE + SAFETY_MARGIN);
@@ -1733,7 +1733,7 @@ void do_put(char *rname,char *lname,file_info *finfo)
     }
 
   if (close_time != 0 && close_time != -1) 
-    close_time -= TimeDiff();
+    close_time -= TimeDiff(close_time);
   
   memset(outbuf,0,smb_size);
   set_message(outbuf,3,2 + strlen(rname),True);
@@ -1741,7 +1741,7 @@ void do_put(char *rname,char *lname,file_info *finfo)
   if (finfo->mtime == 0 || finfo->mtime == -1)
     {
       finfo->mtime = finfo->atime = finfo->ctime = 
-	time(NULL) + GMT_TO_LOCAL*TimeDiff();
+	time(NULL) + GMT_TO_LOCAL*TimeDiff(0);
     }
   
   CVAL(outbuf,smb_com) = SMBcreate;
@@ -1862,7 +1862,7 @@ void do_put(char *rname,char *lname,file_info *finfo)
     struct timeval tp_end;
     int this_time;
 
-    gettimeofday(&tp_end,NULL);
+    GetTimeOfDay(&tp_end);
     this_time = 
       (tp_end.tv_sec - tp_start.tv_sec)*1000 +
 	(tp_end.tv_usec - tp_start.tv_usec)/1000;
@@ -2509,7 +2509,7 @@ void cmd_newer(void)
 
   if (p && (stat(p,&sbuf) == 0))
     {
-      newer_than = sbuf.st_mtime + GMT_TO_LOCAL*TimeDiff();
+      newer_than = sbuf.st_mtime + GMT_TO_LOCAL*TimeDiff(sbuf.st_mtime);
       DEBUG(1,("Getting files newer than %s",asctime(LocalTime(&newer_than,0))));
     }
   else
@@ -2694,8 +2694,10 @@ static BOOL send_login(char *inbuf,char *outbuf,BOOL start_session,BOOL use_setu
       {PROTOCOL_LANMAN1,"MICROSOFT NETWORKS 3.0"},
       {PROTOCOL_LANMAN1,"LANMAN1.0"},
       {PROTOCOL_LANMAN2,"LM1.2X002"},
+#if 0
       {PROTOCOL_NT1,"NT LM 0.12"},
       {PROTOCOL_NT1,"NT LANMAN 1.0"},
+#endif
       {PROTOCOL_LANMAN2,"Samba"},
       {-1,NULL}
     };
@@ -3392,7 +3394,7 @@ void wait_keyboard(char *buffer)
 	
 	f_flags = fcntl(fileno(stdin), F_GETFL, 0);
 	fcntl( fileno(stdin), F_SETFL, f_flags | O_NONBLOCK);
-	readret = read_data( fileno(stdin), &ch, 1,False);
+	readret = read_data( fileno(stdin), &ch, 1);
 	fcntl(fileno(stdin), F_SETFL, f_flags);
 	if (readret == -1)
 	  {
