@@ -327,7 +327,7 @@ int dptr_create(int cnum,char *path, BOOL expect_close,int pid)
   return(i);
 }
 
-#define DPTR_MASK ((uint32)(1<<31))
+#define DPTR_MASK ((uint32)(((uint32)1)<<31))
 
 /****************************************************************************
 fill the 5 byte server reserved dptr field
@@ -488,40 +488,12 @@ BOOL get_dir_entry(int cnum,char *mask,int dirtype,char *fname,int *size,int *mo
 typedef struct
 {
   int pos;
-  BOOL end;
-  void *dirptr;
+  int numentries;
+  int mallocsize;
+  char *data;
+  char *current;
 } Dir;
 
-/*******************************************************************
-open a directory
-********************************************************************/
-void *OpenDir(char *name)
-{
-  Dir *dirp;
-  void *p = opendir(name);
-  if (!p) return(NULL);
-  dirp = (Dir *)malloc(sizeof(Dir));
-  if (!dirp) {
-    closedir(p);
-    return(NULL);
-  }
-  dirp->pos = 0;
-  dirp->end=False;
-  dirp->dirptr = p;
-  return((void *)dirp);
-}
-
-
-/*******************************************************************
-close a directory
-********************************************************************/
-void CloseDir(void *p)
-{
-  Dir *dirp = (Dir *)p;
-  if (!dirp) return;    
-  closedir(dirp->dirptr);
-  free(dirp);
-}
 
 #ifdef USE_DIRECT
 #define DIRECT direct
@@ -529,39 +501,25 @@ void CloseDir(void *p)
 #define DIRECT dirent
 #endif
 
-/*******************************************************************
-read from a directory
-********************************************************************/
-char *ReadDirName(void *p)
+static char *readdirname(void *p)
 {
-  Dir *dirp = (Dir *)p;
   struct DIRECT *ptr;
 
-  if (!dirp || dirp->end) return(NULL);
+  if (!p) return(NULL);
   
-  ptr = (struct DIRECT *)readdir(dirp->dirptr);
-  if (!ptr) {
-    dirp->end = True;
-    return(NULL);
-  }
+  ptr = (struct DIRECT *)readdir(p);
+  if (!ptr) return(NULL);
 
 #ifdef NEXT2
-  if (telldir(dirp->dirptr) < 0)
-    {
-      dirp->end = True;
-      DEBUG(3,("ReadDir encountered null - returning NULL\n"));
-      return(NULL);
-    }
+  if (telldir(p) < 0) return(NULL);
 #endif
 
-  dirp->pos++;
-
 #ifdef SOLARIS
   /* this handles a broken compiler setup, causing a mixture
    of BSD and SYSV headers and libraries */
   {
     static BOOL broken_readdir = False;
-    if (!broken_readdir && !(*ptr->d_name) && strequal("..",ptr->d_name-2))
+    if (!broken_readdir && !(*(ptr->d_name)) && strequal("..",ptr->d_name-2))
       {
 	DEBUG(0,("Your readdir() is broken. You have somehow mixed SYSV and BSD headers and libraries\n"));
 	broken_readdir = True;
@@ -575,6 +533,81 @@ char *ReadDirName(void *p)
 }
 
 
+/*******************************************************************
+open a directory
+********************************************************************/
+void *OpenDir(char *name)
+{
+  Dir *dirp;
+  char *n;
+  void *p = opendir(name);
+  int used=0;
+
+  if (!p) return(NULL);
+  dirp = (Dir *)malloc(sizeof(Dir));
+  if (!dirp) {
+    closedir(p);
+    return(NULL);
+  }
+  dirp->pos = dirp->numentries = dirp->mallocsize = 0;
+  dirp->data = dirp->current = NULL;
+
+  while ((n = readdirname(p))) {
+    int l = strlen(n)+1;
+    if (used + l > dirp->mallocsize) {
+      int s = MAX(used+l,used+2000);
+      char *r;
+      if (!dirp->data)
+	r = (char *)malloc(s);
+      else
+	r = (char *)realloc(dirp->data,s);
+      if (!r) {
+	DEBUG(0,("Out of memory in OpenDir\n"));
+	break;
+      }
+      dirp->data = r;
+      dirp->mallocsize = s;
+      dirp->current = dirp->data;
+    }
+    strcpy(dirp->data+used,n);
+    used += l;
+    dirp->numentries++;
+  }
+
+  closedir(p);
+  return((void *)dirp);
+}
+
+
+/*******************************************************************
+close a directory
+********************************************************************/
+void CloseDir(void *p)
+{
+  Dir *dirp = (Dir *)p;
+  if (!dirp) return;    
+  if (dirp->data) free(dirp->data);
+  free(dirp);
+}
+
+/*******************************************************************
+read from a directory
+********************************************************************/
+char *ReadDirName(void *p)
+{
+  char *ret;
+  Dir *dirp = (Dir *)p;
+
+  if (!dirp || !dirp->current || dirp->pos >= dirp->numentries) return(NULL);
+
+  ret = dirp->current;
+  dirp->current = skip_string(dirp->current,1);
+  dirp->pos++;
+
+  return(ret);
+}
+
+
 /*******************************************************************
 seek a dir
 ********************************************************************/
@@ -584,22 +617,14 @@ BOOL SeekDir(void *p,int pos)
 
   if (!dirp) return(False);
 
-  dirp->end = False;
-
   if (pos < dirp->pos) {
-    rewinddir(dirp->dirptr);
+    dirp->current = dirp->data;
     dirp->pos = 0;
   }
 
-  while (dirp->pos < pos) {
-    if (!readdir(dirp->dirptr)) {
-      dirp->end = True;
-      return(False);      
-    }
-    dirp->pos++;
-  }
+  while (dirp->pos < pos && ReadDirName(p)) ;
 
-  return(True);
+  return(dirp->pos == pos);
 }
 
 /*******************************************************************
