@@ -57,6 +57,7 @@ BOOL bLoaded = False;
 extern int DEBUGLEVEL;
 extern int ReadSize;
 extern pstring user_socket_options;
+extern pstring smbrun_path;
 
 #ifndef GLOBAL_NAME
 #define GLOBAL_NAME "global"
@@ -158,6 +159,8 @@ typedef struct
   char *szInclude;
   char *szPreExec;
   char *szPostExec;
+  char *szRootPreExec;
+  char *szRootPostExec;
   char *szPrintcommand;
   char *szLpqcommand;
   char *szLprmcommand;
@@ -217,6 +220,8 @@ static service sDefault =
   NULL,    /* szInclude */
   NULL,    /* szPreExec */
   NULL,    /* szPostExec */
+  NULL,    /* szRootPreExec */
+  NULL,    /* szRootPostExec */
   NULL,    /* szPrintcommand */
   NULL,    /* szLpqcommand */
   NULL,    /* szLprmcommand */
@@ -307,6 +312,7 @@ struct parm_struct
   {"strip dot",        P_BOOL,    P_GLOBAL, &Globals.bStripDot,         NULL},
   {"password server",  P_STRING,  P_GLOBAL, &Globals.szPasswordServer,  NULL},
   {"socket options",   P_GSTRING, P_GLOBAL, user_socket_options,        NULL},
+  {"smbrun",           P_GSTRING, P_GLOBAL, smbrun_path,                NULL},
   {"log file",         P_STRING,  P_GLOBAL, &Globals.szLogFile,         NULL},
   {"config file",      P_STRING,  P_GLOBAL, &Globals.szConfigFile,      NULL},
   {"hosts equiv",      P_STRING,  P_GLOBAL, &Globals.szHostsEquiv,      NULL},
@@ -347,6 +353,8 @@ struct parm_struct
   {"exec",             P_STRING,  P_LOCAL,  &sDefault.szPreExec,        NULL},
   {"preexec",          P_STRING,  P_LOCAL,  &sDefault.szPreExec,        NULL},
   {"postexec",         P_STRING,  P_LOCAL,  &sDefault.szPostExec,       NULL},
+  {"root preexec",     P_STRING,  P_LOCAL,  &sDefault.szRootPreExec,    NULL},
+  {"root postexec",    P_STRING,  P_LOCAL,  &sDefault.szRootPostExec,   NULL},
   {"revalidate",       P_BOOL,    P_LOCAL,  &sDefault.bRevalidate,      NULL},
   {"default case",     P_INTEGER, P_LOCAL,  &sDefault.iDefaultCase,   handle_case},
   {"case sensitive",   P_BOOL,    P_LOCAL,  &sDefault.bCaseSensitive,   NULL},
@@ -489,16 +497,16 @@ static void init_locals(void)
     {
     case PRINT_BSD:
     case PRINT_AIX:
-      string_initial(&sDefault.szLpqcommand,"lpq -P %p");
-      string_initial(&sDefault.szLprmcommand,"lprm -P %p %j");
-      string_initial(&sDefault.szPrintcommand,"lpr -r -P %p %s");
+      string_initial(&sDefault.szLpqcommand,"lpq -P%p");
+      string_initial(&sDefault.szLprmcommand,"lprm -P%p %j");
+      string_initial(&sDefault.szPrintcommand,"lpr -r -P%p %s");
       break;
 
     case PRINT_SYSV:
     case PRINT_HPUX:
       string_initial(&sDefault.szLpqcommand,"lpstat -o%p");
       string_initial(&sDefault.szLprmcommand,"cancel %p-%j");
-      string_initial(&sDefault.szPrintcommand,"lp -c -d %p %s; rm %s");
+      string_initial(&sDefault.szPrintcommand,"lp -c -d%p %s; rm %s");
       break;
     }
 }
@@ -567,6 +575,8 @@ FN_GLOBAL_INTEGER(lp_printing,&Globals.printing)
 
 FN_LOCAL_STRING(lp_preexec,szPreExec)
 FN_LOCAL_STRING(lp_postexec,szPostExec)
+FN_LOCAL_STRING(lp_rootpreexec,szRootPreExec)
+FN_LOCAL_STRING(lp_rootpostexec,szRootPostExec)
 FN_LOCAL_STRING(lp_servicename,szService)
 FN_LOCAL_STRING(lp_pathname,szPath)
 FN_LOCAL_STRING(lp_dontdescend,szDontdescend)
