@@ -72,6 +72,8 @@ extern int  lp_maxpacket(void);
 extern char *lp_comment(int iService);
 extern char *lp_preexec(int iService);
 extern char *lp_postexec(int iService);
+extern char *lp_rootpreexec(int iService);
+extern char *lp_rootpostexec(int iService);
 extern char *lp_servicename(int iService);
 extern char *lp_pathname(int iService);
 extern char *lp_username(int iService);
