@@ -36,7 +36,7 @@
 #define MAXSTATUS 1000
 
 /* max number of directories open at once */
-#define MAXDIR 20
+#define MAXDIR 30
 
 #define WORDMAX 0xFFFF
 
@@ -78,4 +78,11 @@
 #define PRIME_NMBD 1
 #endif
 
+/* do you want session setups at user level security with a invalid
+   password to be rejected or allowed in as guest? WinNT rejects them
+   but it can be a pain as it means "net view" needs to use a password */
+#ifndef GUEST_SESSSETUP
+#define GUEST_SESSSETUP 0
+#endif
+
 #endif
