@@ -327,10 +327,10 @@ void add_group_name(char *name)
   if (i < 0) 
     return;
 
-  strupper(name);
   memset((char *)&names[i].ip,0,sizeof(names[i].ip));
 
   strcpy(names[i].name,name);
+  strupper(names[i].name);
   strcpy(names[i].flags,"G");
   names[i].nb_flags |= 0x80;
 
@@ -398,7 +398,7 @@ int nmb_recv_len = 0;
 /****************************************************************************
 receive a name message
 ****************************************************************************/
-BOOL receive_nmb(char *buffer,int timeout)
+int receive_nmb(char *buffer,int timeout)
 {
   int ret = read_max_udp(Client,buffer,BUFFER_SIZE,timeout);
 
@@ -415,14 +415,14 @@ BOOL receive_nmb(char *buffer,int timeout)
     }
   
   if (ret <= 1)
-    return False;
+    return 0;
 
   log_in(buffer,ret);
 
   DEBUG(3,("received packet from (%s) nmb_len=%d len=%d\n",
 	inet_ntoa(lastip),nmb_len(buffer),ret));
 
-  return(True);
+  return(ret);
 }
 
 /****************************************************************************
@@ -620,7 +620,7 @@ BOOL name_query(char *inbuf,char *outbuf,char *name,
 
   RSSVAL(outbuf,0,name_trn_id);
   CVAL(outbuf,2) = 0x1;
-  CVAL(outbuf,3) = (1<<4) | 0x0;
+  CVAL(outbuf,3) = (1<<4);
   RSSVAL(outbuf,4,1);
   RSSVAL(outbuf,6,0);
   RSSVAL(outbuf,8,0);
@@ -912,9 +912,6 @@ void reply_name_query(char *inbuf,char *outbuf)
 	}
 
       DEBUG(2,(" sending positive reply (%s)\n",inet_ntoa(retip)));
-
-      /* add the name for future reference */
-      add_host_name(qname,&retip);
     }
 
   
@@ -1237,6 +1234,7 @@ void process(char *lookup)
 {
   static int trans_num = 0;
   time_t timer = 0;
+  int nread;
   
   if (InBuffer) free(InBuffer);
   if (OutBuffer) free(OutBuffer);
@@ -1263,15 +1261,17 @@ void process(char *lookup)
     {
       if (!browse)
 	{
-	  if (!receive_nmb(InBuffer,is_daemon?0:idle_timeout))	
-	    return;
+	  if (!(nread = receive_nmb(InBuffer,is_daemon?0:idle_timeout)))
+	    {
+	      if (is_daemon) continue;
+	      return;
+	    }
 	}
       else
 	{
 	  fd_set fds;
 	  int selrtn;
 	  struct timeval timeout;
-	  int nread;
 
 	  if (!timer || (time(NULL) - timer) > 60)
 	    {
@@ -1299,7 +1299,7 @@ void process(char *lookup)
 	    continue;
 	}
 
-      if (nmb_len(InBuffer) <= 0)
+      if (nread < 4)
 	continue;
 
       if (DEBUGLEVEL > 2)
