@@ -54,7 +54,7 @@ void load_remaining(char *inbuf)
 
   if (buflen>0)
     {
-      if (read_data(Client,smb_buf(inbuf),buflen,False) != buflen)
+      if (read_data(Client,smb_buf(inbuf),buflen) != buflen)
 	exit_server("Load remaining failed");
     }
 }  
@@ -364,7 +364,7 @@ int reply_sesssetup_and_X(char *inbuf,char *outbuf,int length,int bufsize)
       /* now check if it's a valid username/password */
       if (!guest && !password_ok(user,smb_apasswd, NULL))
 	{
-#if 1
+#if !GUEST_SESSSETUP
 	  if (lp_security() == SEC_USER)
 	    return(ERROR(ERRSRV,ERRbadpw));
 #endif
@@ -498,7 +498,7 @@ int reply_getatr(char *inbuf,char *outbuf)
   outsize = set_message(outbuf,10,0,True);
 
   SSVAL(outbuf,smb_vwv0,mode);
-  SIVAL(outbuf,smb_vwv1,mtime + GMT_TO_LOCAL * TimeDiff());
+  SIVAL(outbuf,smb_vwv1,mtime + GMT_TO_LOCAL * TimeDiff(mtime));
   SIVAL(outbuf,smb_vwv3,size);
 
   if (Protocol >= PROTOCOL_NT1) {
@@ -540,7 +540,7 @@ int reply_setatr(char *inbuf,char *outbuf)
   if (check_name(fname,cnum))
     ok =  (chmod(fname,unix_mode(cnum,mode)) == 0);
   if (ok && mtime != 0)
-    ok = set_filetime(fname,mtime + LOCAL_TO_GMT * TimeDiff());
+    ok = set_filetime(fname,mtime + LOCAL_TO_GMT * TimeDiff(mtime));
   
   if (!ok)
     return(UNIXERROR(ERRDOS,ERRnoaccess));
@@ -940,7 +940,7 @@ int reply_open(char *inbuf,char *outbuf)
   outsize = set_message(outbuf,7,0,True);
   SSVAL(outbuf,smb_vwv0,fnum);
   SSVAL(outbuf,smb_vwv1,fmode);
-  SIVAL(outbuf,smb_vwv2,mtime + GMT_TO_LOCAL * TimeDiff());
+  SIVAL(outbuf,smb_vwv2,mtime + GMT_TO_LOCAL * TimeDiff(mtime));
   SIVAL(outbuf,smb_vwv4,size);
   SSVAL(outbuf,smb_vwv6,rmode);
   
@@ -1058,7 +1058,7 @@ int reply_open_and_X(char *inbuf,char *outbuf,int length,int bufsize)
   SSVAL(outbuf,smb_vwv1,(chain_size+outsize)-4);
   SSVAL(outbuf,smb_vwv2,fnum);
   SSVAL(outbuf,smb_vwv3,fmode);
-  SIVAL(outbuf,smb_vwv4,mtime + GMT_TO_LOCAL * TimeDiff());
+  SIVAL(outbuf,smb_vwv4,mtime + GMT_TO_LOCAL * TimeDiff(mtime));
   SIVAL(outbuf,smb_vwv6,size);
   SSVAL(outbuf,smb_vwv8,rmode);
 
@@ -1528,6 +1528,7 @@ int reply_read(char *inbuf,char *outbuf,int length,int bufsize)
   outsize += nread;
   SSVAL(outbuf,smb_vwv0,nread);
   SSVAL(outbuf,smb_vwv5,nread+3);
+  CVAL(smb_buf(outbuf),0) = 1;
   SSVAL(smb_buf(outbuf),1,nread);
   
   DEBUG(3,("%s read fnum=%d cnum=%d num=%d nread=%d\n",timestring(),fnum,cnum,numtoread,nread));
@@ -1711,7 +1712,7 @@ int reply_writebraw(char *inbuf,char *outbuf,int length,int bufsize,BOOL partial
 	      if (!read_buf)
 		DEBUG(0,("Out of memory in writebraw!\n"));
 
-	      if(read_data(Client,read_buf,numtowrite,False) != numtowrite) {
+	      if(read_data(Client,read_buf,numtowrite) != numtowrite) {
 		exit_server("second writebraw failed (2)");
 	      }
 
@@ -1976,11 +1977,11 @@ int reply_write_and_X(char *inbuf,char *outbuf,int length,int bufsize,BOOL parti
 	      int buflen = (smb_len(inbuf)+4) - 
 		(smb_vwv + (CVAL(inbuf,smb_wct)+1)*2);
 	      int l = (smb_doff+4)-smb_buf_ofs(inbuf);
-	      if (l>0 && read_data(Client,smb_buf(inbuf),l,False) != l)
+	      if (l>0 && read_data(Client,smb_buf(inbuf),l) != l)
 		exit_server("writeX partial failed");
 	      nwritten = transfer_file(Client,fd,smb_dsize,NULL,0);
 	      buflen -= (l + smb_dsize);
-	      if (read_data(Client,data+smb_dsize,buflen,False) != buflen)
+	      if (read_data(Client,data+smb_dsize,buflen) != buflen)
 		exit_server("writeX partial2 failed");
 	      partial = False;
 	    }
@@ -2024,7 +2025,7 @@ int reply_lseek(char *inbuf,char *outbuf)
   int cnum,fnum;
   uint32 startpos;
   int32 res=-1;
-  int mode;
+  int mode,umode;
   int outsize = 0;
   BOOL ok = False;
   
@@ -2037,24 +2038,30 @@ int reply_lseek(char *inbuf,char *outbuf)
       if(HAS_CACHED_ERROR(fnum))
 	return (CACHED_ERROR(fnum));
     }
-  mode = SVAL(inbuf,smb_vwv1);
+  mode = SVAL(inbuf,smb_vwv1) & 3;
   startpos = IVAL(inbuf,smb_vwv2);
-  
+
+  switch (mode & 3) 
     {
-      if (OPEN_FNUM(fnum) && (Files[fnum].cnum == cnum))
-	{
-	  res = lseek(Files[fnum].fd,startpos,mode);
-	  Files[fnum].pos = -1;
-	}
-      ok = True;
+    case 0: umode = SEEK_SET; break;
+    case 1: umode = SEEK_CUR; break;
+    case 2: umode = SEEK_END; break;
+    default:
+      umode = SEEK_SET; break;
     }
   
+  if (OPEN_FNUM(fnum) && (Files[fnum].cnum == cnum))
+    {
+      res = lseek(Files[fnum].fd,startpos,umode);
+      Files[fnum].pos = -1;
+    }
+  ok = True;
   
-  if ((res < 0) || !ok)
+  if (!ok)
     return(UNIXERROR(ERRDOS,ERRnoaccess));
   
   outsize = set_message(outbuf,2,0,True);
-  SIVAL(outbuf,smb_vwv0,res);
+  SIVALS(outbuf,smb_vwv0,res);
   
   DEBUG(3,("%s lseek fnum=%d cnum=%d pos=%d\n",timestring(),fnum,cnum,startpos));
   
@@ -2149,7 +2156,7 @@ int reply_close(char *inbuf,char *outbuf)
 	  if (mtime == 0 || mtime == -1)
 	    DEBUG(5,("not setting null date\n"));
 	  else
-	    set_filetime(Files[fnum].name,mtime + LOCAL_TO_GMT * TimeDiff());
+	    set_filetime(Files[fnum].name,mtime + LOCAL_TO_GMT * TimeDiff(mtime));
 
 	  ok = True;
 	}
@@ -2218,7 +2225,7 @@ int reply_writeclose(char *inbuf,char *outbuf)
       if (mtime == 0 || mtime == -1)
 	DEBUG(5,("not setting null date\n"));
       else
-	set_filetime(Files[fnum].name,mtime + LOCAL_TO_GMT * TimeDiff());
+	set_filetime(Files[fnum].name,mtime + LOCAL_TO_GMT * TimeDiff(mtime));
     }
   
   DEBUG(3,("%s writeclose fnum=%d cnum=%d num=%d wrote=%d (numopen=%d)\n",
@@ -3136,8 +3143,8 @@ int reply_setattrE(char *inbuf,char *outbuf)
 
       unix_times.actime = make_unix_date2(inbuf+smb_vwv3);
       unix_times.modtime = make_unix_date2(inbuf+smb_vwv5);
-      unix_times.actime += LOCAL_TO_GMT*TimeDiff();
-      unix_times.modtime += LOCAL_TO_GMT*TimeDiff();
+      unix_times.actime += LOCAL_TO_GMT*TimeDiff(unix_times.actime);
+      unix_times.modtime += LOCAL_TO_GMT*TimeDiff(unix_times.modtime);
 
       /* Set the date on this file */
       if(utime(Files[fnum].name, &unix_times))
