@@ -56,6 +56,7 @@ extern int case_default;
 extern BOOL case_sensitive;
 extern BOOL case_preserve;
 extern BOOL case_mangle;
+extern time_t smb_last_time;
 
 extern pstring user_socket_options;
 
@@ -239,6 +240,9 @@ BOOL scan_directory(char *path, char *name, char *mangled_map)
   if (*path == 0)
     path = ".";
 
+  if (mangled)
+    check_mangled_stack(name,mangled_map);
+
   /* open the directory */
   if (!(cur_dir = OpenDir(path))) 
     {
@@ -483,6 +487,14 @@ void open_file(int fnum,int cnum,char *fname1,int flags,int mode)
   if (flags == O_WRONLY)
     DEBUG(3,("Bug in client? Set O_WRONLY without O_CREAT\n"));
 
+#if UTIME_WORKAROUND
+  /* XXXX - is this OK?? */
+  /* this works around a utime bug but can cause other problems */
+  if ((flags & (O_WRONLY|O_RDWR)) && (flags & O_CREAT) && !(flags & O_APPEND))
+    unlink(fname);
+#endif
+
+
   Files[fnum].fd = open(fname,flags,mode);
 
   /* Fix for files ending in '.' */
@@ -706,7 +718,7 @@ BOOL become_service(int cnum,BOOL do_chdir)
       return(False);
     }
 
-  Connections[cnum].lastused = time(NULL);
+  Connections[cnum].lastused = smb_last_time;
 
   snum = SNUM(cnum);
   
@@ -1735,6 +1747,16 @@ int make_connection(char *service,char *user,char *password,char *dev,int vuid)
 
   Connections[cnum].open = True;
 
+  /* execute any "root preexec = " line */
+  if (*lp_rootpreexec(SNUM(cnum)))
+    {
+      pstring cmd;
+      strcpy(cmd,lp_rootpreexec(SNUM(cnum)));
+      standard_sub(cnum,cmd);
+      DEBUG(5,("cmd=%s\n",cmd));
+      smbrun(cmd,NULL);
+    }
+
   if (!become_user(cnum))
     {
       DEBUG(0,("Can't become connected user!\n"));
@@ -1751,6 +1773,7 @@ int make_connection(char *service,char *user,char *password,char *dev,int vuid)
 
   string_set(&Connections[cnum].origpath,Connections[cnum].connectpath);
 
+#if SOFTLINK_OPTIMISATION
   /* resolve any soft links early */
   {
     pstring s;
@@ -1759,6 +1782,7 @@ int make_connection(char *service,char *user,char *password,char *dev,int vuid)
     string_set(&Connections[cnum].connectpath,s);
     ChDir(Connections[cnum].connectpath);
   }
+#endif
 
   num_connections_open++;
   add_session_user(user);
@@ -1908,7 +1932,7 @@ int reply_lanman1(char *outbuf)
   SSVAL(outbuf,smb_vwv5,raw); /* tell redirector we support
 				 readbraw writebraw (possibly) */
   SIVAL(outbuf,smb_vwv6,getpid());
-  SSVAL(outbuf,smb_vwv10, (TimeDiff() / 60) );
+  SSVAL(outbuf,smb_vwv10, (TimeDiff(0) / 60) );
 
   put_dos_date(outbuf,smb_vwv8,time(NULL));
 
@@ -1933,7 +1957,7 @@ int reply_lanman2(char *outbuf)
   SSVAL(outbuf,smb_vwv5,raw); /* tell redirector we support
 				 readbraw writebraw (possibly) */
   SIVAL(outbuf,smb_vwv6,getpid());
-  SSVAL(outbuf,smb_vwv10, (TimeDiff() / 60) );
+  SSVAL(outbuf,smb_vwv10, (TimeDiff(0) / 60) );
 
   put_dos_date(outbuf,smb_vwv8,time(NULL));
 
@@ -1981,7 +2005,7 @@ int reply_nt1(char *outbuf)
   SIVAL(outbuf,smb_vwv7+1,getpid()); /* session key */
   SIVAL(outbuf,smb_vwv9+1,capabilities); /* capabilities */
   put_long_date(outbuf+smb_vwv11+1,time(NULL));
-  SSVALS(outbuf,smb_vwv15+1, (TimeDiff() / 60) );
+  SSVALS(outbuf,smb_vwv15+1, (TimeDiff(0) / 60) );
 
   Protocol = PROTOCOL_NT1;
 
@@ -2495,6 +2519,16 @@ void close_cnum(int cnum)
       unbecome_user();
     }
 
+  unbecome_user();
+  /* execute any "root postexec = " line */
+  if (*lp_rootpostexec(SNUM(cnum)))
+    {
+      pstring cmd;
+      strcpy(cmd,lp_rootpostexec(SNUM(cnum)));
+      standard_sub(cnum,cmd);
+      smbrun(cmd,NULL);
+    }
+
   Connections[cnum].open = False;
   num_connections_open--;
   if (Connections[cnum].ngroups && Connections[cnum].groups)
@@ -2672,7 +2706,7 @@ BOOL claim_connection(int cnum,char *name,int max_connections,BOOL Clear)
   crec.uid = Connections[cnum].uid;
   crec.gid = Connections[cnum].gid;
   StrnCpy(crec.name,lp_servicename(snum),sizeof(crec.name)-1);
-  crec.start = time(NULL) + GMT_TO_LOCAL*TimeDiff();
+  crec.start = time(NULL) + GMT_TO_LOCAL*TimeDiff(0);
   {
     extern struct from_host Client_info;
     StrnCpy(crec.machine,Client_info.name,sizeof(crec.machine)-1);
@@ -2898,7 +2932,7 @@ int switch_message(int type,char *inbuf,char *outbuf,int size,int bufsize,BOOL p
   struct timeval msg_end_time;
   static unsigned long total_time = 0;
 
-  gettimeofday(&msg_start_time,NULL);
+  GetTimeOfDay(&msg_start_time);
 #endif
 
   if (pid == -1)
@@ -2938,7 +2972,7 @@ int switch_message(int type,char *inbuf,char *outbuf,int size,int bufsize,BOOL p
 	  if (partial && buflen>0 && !(flags&PARTIAL))
 	    {
 	      partial = False;
-	      if (read_data(Client,smb_buf(inbuf),buflen,False) != buflen)
+	      if (read_data(Client,smb_buf(inbuf),buflen) != buflen)
 		exit_server("switch partial failed");
 	    }
 
@@ -2979,7 +3013,7 @@ int switch_message(int type,char *inbuf,char *outbuf,int size,int bufsize,BOOL p
     }
 
 #if PROFILING
-  gettimeofday(&msg_end_time,NULL);
+  GetTimeOfDay(&msg_end_time);
   if (!(smb_messages[match].flags & TIME_INIT))
     {
       smb_messages[match].time = 0;
@@ -3109,6 +3143,8 @@ int construct_reply(char *inbuf,char *outbuf,int size,int bufsize)
   int outsize = 0;
   int msg_type = CVAL(inbuf,0);
 
+  smb_last_time = time(NULL);
+
   chain_size = 0;
 
   memset(outbuf,0,smb_size);
@@ -3175,6 +3211,7 @@ void process(void )
       int type;
       int deadtime = lp_deadtime()*60;
       int counter;
+      int last_keepalive=0;
 
       if (deadtime <= 0)
 	deadtime = 60*60*12; /* 12 hours default timeout */
@@ -3189,6 +3226,7 @@ void process(void )
 	  int i;
 	  time_t t;
 	  BOOL allidle = True;
+	  extern int keepalive;
 
 	  /* check for socket failure */
 	  if (errno == EBADF)
@@ -3207,6 +3245,11 @@ void process(void )
 	  if (num_connections_open==0 && counter >= 30)
 	    return;
 
+	  if (keepalive && (counter-last_keepalive)>keepalive) {
+	    if (!send_keepalive(Client)) return;
+	    last_keepalive = counter;
+	  }
+
 	  /* check for connection timeouts */
 	  for (i=0;i<MAX_CONNECTIONS;i++)
 	    if (Connections[i].open)
