@@ -674,7 +674,8 @@ int write_socket(int fd,char *buf,int len);
 void close_sockets(void );
 int write_with_timeout(int fd, char *buf, int length, long time_out);
 BOOL send_smb(char *buffer);
-int read_data(int fd,char *buffer,int N,BOOL keepalives);
+BOOL send_keepalive(int client);
+int read_data(int fd,char *buffer,int N);
 int smb_len(char *buf);
 BOOL receive_smb(char *buffer,int timeout, BOOL partial);
 void show_msg(char *buf);
@@ -731,9 +732,10 @@ char *validate_group(char *group,char *password,int snum);
 int chain_reply(int type,char *inbuf,char *inbuf2,char *outbuf,char *outbuf2,int size,int bufsize);
 void close_cnum(int cnum);
 char *smb_errstr(char *inbuf);
+void GetTimeOfDay(struct timeval *tval);
 struct tm *LocalTime(time_t *t,int);
 time_t TimeLocal(struct tm *tm,int);
-int TimeDiff(void);
+int TimeDiff(time_t t);
 void replacestr(char *str1, char *str2, int start, int n);
 void openstr(char *s, int start, int n);
 void closestr(char *s, int start, int n);
