@@ -905,9 +905,9 @@ int call_trans2qfsinfo(char *inbuf, char *outbuf, int length, int bufsize,
       strcpy(pdata+4,sname);      
       break;
     case SMB_QUERY_FS_VOLUME_INFO:      
-      data_len = 13 + strlen(sname);
-      SIVAL(pdata,8,strlen(sname));
-      strcpy(pdata+13,sname);      
+      data_len = 17 + strlen(sname);
+      SIVAL(pdata,12,strlen(sname));
+      strcpy(pdata+17,sname);      
       break;
     case SMB_QUERY_FS_SIZE_INFO:
       {
@@ -965,10 +965,9 @@ int call_trans2qfilepathinfo(char *inbuf, char *outbuf, int length,
   char *params = *pparams;
   char *pdata = *ppdata;
   uint16 tran_call = SVAL(inbuf, smb_setup0);
-  uint16 info_level = SVAL(params,2);
+  uint16 info_level;
   int mode=0;
   int size=0;
-  int16 fnum = SVAL(params,0);
   unsigned int data_size;
   struct stat sbuf;
   pstring fname1;
@@ -976,10 +975,10 @@ int call_trans2qfilepathinfo(char *inbuf, char *outbuf, int length,
   char *p;
   int l,pos;
 
-  DEBUG(3,("call_trans2qfilepathinfo fnum=%d, level=%d tran_call=%d\n",
-	   fnum,info_level,tran_call));
 
   if (tran_call == TRANSACT2_QFILEINFO) {
+    int16 fnum = SVAL(params,0);
+    info_level = SVAL(params,2);
     if (!OPEN_FNUM(fnum))
       return(ERROR(ERRDOS,ERRbadfid));
     if (Protocol >= PROTOCOL_LANMAN1) {
@@ -995,6 +994,7 @@ int call_trans2qfilepathinfo(char *inbuf, char *outbuf, int length,
     pos = lseek(Files[fnum].fd,0,SEEK_CUR);
   } else {
     /* qpathinfo */
+    info_level = SVAL(params,0);
     fname = &fname1[0];
     strcpy(fname,&params[6]);
     unix_convert(fname,cnum);
@@ -1006,6 +1006,9 @@ int call_trans2qfilepathinfo(char *inbuf, char *outbuf, int length,
   }
 
 
+  DEBUG(3,("call_trans2qfilepathinfo %s level=%d\n",
+	   fname,info_level));
+
   p = strrchr(fname,'/'); 
   if (!p) 
     p = fname;
@@ -1023,7 +1026,6 @@ int call_trans2qfilepathinfo(char *inbuf, char *outbuf, int length,
   switch (info_level) 
     {
     case 1:
-    case 2:
       data_size = (info_level==1?22:26);
       put_dos_date2(pdata,l1_fdateCreation,sbuf.st_ctime);
       put_dos_date2(pdata,l1_fdateLastAccess,sbuf.st_atime);
@@ -1124,7 +1126,7 @@ int call_trans2setfilepathinfo(char *inbuf, char *outbuf, int length, int bufsiz
   char *params = *pparams;
   char *pdata = *ppdata;
   uint16 tran_call = SVAL(inbuf, smb_setup0);
-  uint16 info_level = SVAL(params,2);
+  uint16 info_level;
   int mode=0;
   int size=0;
   struct utimbuf tvs;
@@ -1133,13 +1135,12 @@ int call_trans2setfilepathinfo(char *inbuf, char *outbuf, int length, int bufsiz
   char *fname;
   int fd = -1;
 
-  DEBUG(3,("call_trans2setfileinfo %s info_level = %d\n", fname, info_level));
-
   if (!CAN_WRITE(cnum))
     return(ERROR(ERRSRV,ERRaccess));
 
   if (tran_call == TRANSACT2_SETFILEINFO) {
     int16 fnum = SVAL(params,0);
+    info_level = SVAL(params,2);    
 
     if (!OPEN_FNUM(fnum))
       return(ERROR(ERRDOS,ERRbadfid));
@@ -1158,6 +1159,7 @@ int call_trans2setfilepathinfo(char *inbuf, char *outbuf, int length, int bufsiz
     }
   } else {
     /* set path info */
+    info_level = SVAL(params,0);    
     fname = fname1;
     strcpy(fname,&params[6]);
     unix_convert(fname,cnum);
@@ -1170,6 +1172,9 @@ int call_trans2setfilepathinfo(char *inbuf, char *outbuf, int length, int bufsiz
     }    
   }
 
+  DEBUG(3,("call_trans2setfilepathinfo %s info_level %d\n",fname,info_level));
+
+
   /* Realloc the parameter and data sizes */
   params = *pparams = Realloc(*pparams,2); SSVAL(params,0,0);
   if(params == NULL)
@@ -1183,11 +1188,12 @@ int call_trans2setfilepathinfo(char *inbuf, char *outbuf, int length, int bufsiz
   switch (info_level)
     {
     case 1:
-    case 2:
       tvs.actime = make_unix_date2(pdata+l1_fdateLastAccess);
       tvs.modtime = make_unix_date2(pdata+l1_fdateLastWrite);
       mode = SVAL(pdata,l1_attrFile);
       size = IVAL(pdata,l1_cbFile);
+      DEBUG(4,("got size=0x%X mode=0x%X actime=0x%X modtime=0x%X\n",
+	       size,mode,tvs.actime,tvs.modtime));
       break;
 
     case SMB_SET_FILE_BASIC_INFO:
@@ -1204,6 +1210,9 @@ int call_trans2setfilepathinfo(char *inbuf, char *outbuf, int length, int bufsiz
       size = IVAL(pdata,0);
       break;
 
+    case 2: /* this is for LanServer on OS/2 - we just ignore EAs */
+      break;
+
     case SMB_SET_FILE_DISPOSITION_INFO: /* not supported yet */
     case SMB_SET_FILE_ALLOCATION_INFO: /* not supported yet */
     default:
