@@ -89,6 +89,32 @@ Byte offset   Type     name                description
 #define l2_cchName 26
 #define l2_achName 27
 
+
+/**********************************************************
+For DosFindFirst/DosFindNext - level 260
+
+typedef struct _FILEFINDBUF260 {
+Byte offset   Type     name                description
+-------------+-------+-------------------+--------------
+0              ULONG  NextEntryOffset;
+4              ULONG  FileIndex;
+8              LARGE_INTEGER CreationTime;
+16             LARGE_INTEGER LastAccessTime;
+24             LARGE_INTEGER LastWriteTime;
+32             LARGE_INTEGER ChangeTime;
+40             LARGE_INTEGER EndOfFile;
+48             LARGE_INTEGER AllocationSize;
+56             ULONG FileAttributes;
+60             ULONG FileNameLength;
+64             ULONG EaSize;
+68             CHAR ShortNameLength;
+70             UNICODE ShortName[12];
+94             UNICODE FileName[];
+*************************************************************/
+
+#define l260_achName 94
+
+
 /**********************************************************
 For DosQueryPathInfo/DosQueryFileInfo/DosSetPathInfo/
 DosSetFileInfo - level 1
@@ -165,11 +191,38 @@ Byte offset   Type     name                description
 } FSINFO;
 *************************************************************/
 
+#define SMB_QUERY_FS_LABEL_INFO			0x101
+#define SMB_QUERY_FS_VOLUME_INFO		0x102
+#define SMB_QUERY_FS_SIZE_INFO			0x103
+#define SMB_QUERY_FS_DEVICE_INFO		0x104
+#define SMB_QUERY_FS_ATTRIBUTE_INFO		0x105
+
+
 #define l2_vol_fdateCreation 0
 #define l2_vol_cch 4
 #define l2_vol_szVolLabel 5
 
 
+#define SMB_QUERY_FILE_BASIC_INFO	0x101
+#define SMB_QUERY_FILE_STANDARD_INFO	0x102
+#define SMB_QUERY_FILE_EA_INFO		0x103
+#define SMB_QUERY_FILE_NAME_INFO	0x104
+#define SMB_QUERY_FILE_ALLOCATION_INFO	0x105
+#define SMB_QUERY_FILE_END_OF_FILEINFO	0x106
+#define SMB_QUERY_FILE_ALL_INFO		0x107
+#define SMB_QUERY_FILE_ALT_NAME_INFO	0x108
+#define SMB_QUERY_FILE_STREAM_INFO	0x109
+
+#define SMB_FIND_FILE_DIRECTORY_INFO		0x101
+#define SMB_FIND_FILE_FULL_DIRECTORY_INFO	0x102
+#define SMB_FIND_FILE_NAMES_INFO		0x103
+#define SMB_FIND_FILE_BOTH_DIRECTORY_INFO	0x104
+
+#define SMB_SET_FILE_BASIC_INFO		0x101
+#define SMB_SET_FILE_DISPOSITION_INFO	0x102
+#define SMB_SET_FILE_ALLOCATION_INFO	0x103
+#define SMB_SET_FILE_END_OF_FILE_INFO	0x104
+
 #define DIRLEN_GUESS (45+MAX(l1_achName,l2_achName))
 
 /* Function prototypes */
@@ -184,18 +237,6 @@ int call_trans2findfirst(char *inbuf, char *outbuf, int bufsize, int cnum,
 int call_trans2setfsinfo(char *inbuf, char *outbuf, int length, int bufsize,
 			int cnum, char **pparams, char **pdata);
 
-int call_trans2qpathinfo(char *inbuf, char *outbuf, int length, int bufsize,
-			int cnum, char **pparams, char **pdata);
-
-int call_trans2setpathinfo(char *inbuf, char *outbuf, int length, int bufsize,
-			int cnum, char **pparams, char **pdata);
-
-int call_trans2qfileinfo(char *inbuf, char *outbuf, int length, int bufsize,
-			int cnum, char **pparams, char **pdata);
-
-int call_trans2setfileinfo(char *inbuf, char *outbuf, int length, int bufsize,
-			int cnum, char **pparams, char **pdata);
-
 int call_trans2mkdir(char *inbuf, char *outbuf, int length, int bufsize,
 			int cnum, char **pparams, char **pdata);
 
